(defun transform-plot(A x &key no-zeros)
  "
transform-plot(A x): 

A is a matrix
x is a matrix of vectors to be transformed

;; Examples:
 (def a
     (matrix '(3 3)
      (list 0 0 0 0 1 0 0 0 1)
      )
     )
 (def x
     (bind-rows
      (vector 1 1 0)
      (vector 2 1 1)
      (vector 1 0 1)
      )
     )
 (transform-plot a x)
"
  (let* (
	 (x (if (matrixp x) x (apply #'bind-rows x)))
	 (y (row-lists (matmult A x)))
	 (x (row-lists x))
	 (maxes (mapcar (lambda(x y) (max (combine x y))) x y))
	 (mins (mapcar (lambda(x y) (min (combine x y))) x y))
	 (n (length (first x)))
	 (x (if no-zeros
		x
	      (mapcar (lambda(x) (combine (transpose (list (repeat 0 n) x)))) x)))
	 (y (if no-zeros
		y
	      (mapcar (lambda(x) (combine (transpose (list (repeat 0 n) x)))) y)))
	 (plot (plotter x))
	 )
    (send plot :showing-axes nil)
    (send plot :add-plot-item
	  (list
	   'lines
	   (elt y 0)
	   (elt y 1)
	   (elt y 2)
	   :color 'yellow
	   )
	  )
    (send plot :range 0 (elt mins 0) (elt maxes 0))
    (send plot :range 1 (elt mins 1) (elt maxes 1))
    (send plot :range 2 (elt mins 2) (elt maxes 2))
    (send plot :scale-type 'fixed)
    plot
    )
  )

(let ()
  (title "projections")
  (transform-plot
   [[1 0 0][0 1 0][0 0 0]]
   [[1 2 3][-1 1 -1][1 1 1]]
   ) 
  )

(let ()
  (title "shears")
  (transform-plot
   [[1 3 0][0 1 0][0 0 0]]
   [[0 2 2 2 2][2 0 2 4/3 2/3][0 0 0 0 0]]
   ) 
  )
(let ()
  (title "shears")
  (transform-plot
   [[1 3 0][0 1 0][0 0 0]]
   [[0 0 2 2 0][0 2 2 0 0][0 0 0 0 0]]
   :no-zeros t
   ) 
  )

(let ()
  (title "contraction")
  (transform-plot
   [[.5 0 0][0 .5 0][0 0 .5]]
   [[0 0 2 2 0][0 2 2 0 0][0 0 0 0 0]]
   :no-zeros t
   ) 
  )
(let ()
  (title "dilation")
  (transform-plot
   [[2 0 0][0 2 0][0 0 2]]
   [[0 0 2 2 0][0 2 2 0 0][0 0 0 0 0]]
   :no-zeros t
   ) 
  )

(let ()
  (title "rotation - 90 degrees")
  (transform-plot
   [[0 -1 0][1 0 0][0 0 0]]
   [[0 4 6 2 0][0 1 4 3 0][0 0 0 0 0]]
   :no-zeros t
   ) 
  )
(let ()
  (title "rotation - -90 degrees")
  (transform-plot
   [[0 1 0][-1 0 0][0 0 0]]
   [[0 4 6 2 0][0 1 4 3 0][0 0 0 0 0]]
   :no-zeros t
   ) 
  )
(let ()
  (title "rotation - 180 degrees")
  (transform-plot
   (matmult [[0 1 0][-1 0 0][0 0 0]] [[0 1 0][-1 0 0][0 0 0]])
   [[0 4 6 2 0][0 1 4 3 0][0 0 0 0 0]]
   :no-zeros t
   ) 
  )



